@@ -157,23 +157,22 @@ class PixelMapFit:
             model = lm.Model(background_model, independent_vars=['time'])
             for j in mask:
                 model += lm.Model(lc_model,independent_vars=['time'],prefix='f{0:d}'.format(j))
-                for i in range(np.where(mask.value==j)[0][0]+1):
+                for i in range(np.where(mask==j)[0][0]+1):
                     model.set_param_hint('f{0:d}phase'.format(mask[i]), min = -np.pi, max = np.pi ,value= initial_phase[mask][i],vary = False)
                     model.set_param_hint('f{0:d}amp'.format(mask[i]), value = initial_amp[mask][i],vary=False)
                     model.set_param_hint('height', value= np.nanmean(flux),vary=False)
                     model.set_param_hint('f{0:d}freq'.format(mask[i]),value = frequency_list[mask][i], vary = False)
 
-            params = model.make_params()
-            #params['f{0:d}amp'.format(j)].set(value = initial_amp[j],vary=False)
-            params['f{0:d}phase'.format(j)].set(vary=True)
-            params['f{0:d}phase'.format(j)].set(value = initial_phase[j])
-            params['f{0:d}phase'.format(j)].set(brute_step=np.pi/10)
-            result = model.fit(corrected_lc.flux.value,params,time=times,method = 'brute')
-            initial_phase[j]=result.best_values['f{0:d}phase'.format(j)]    
+                params = model.make_params()
+                #params['f{0:d}amp'.format(j)].set(value = initial_amp[j],vary=False)
+                params['f{0:d}phase'.format(j)].set(vary=True)
+                params['f{0:d}phase'.format(j)].set(value = initial_phase[j])
+                params['f{0:d}phase'.format(j)].set(brute_step=np.pi/10)
+                result = model.fit(corrected_lc.flux.value,params,time=times,method = 'brute')
+                initial_phase[j]=result.best_values['f{0:d}phase'.format(j)]    
 
             return initial_phase
 
-self.initial_phases = Obtain_Initial_Phase(self.tpf,self.corrected_lc,self.frequency_list)
 
 #             flux = corrected_lc.flux.value
 #             times = corrected_lc.time.value - np.nanmean(corrected_lc.time.value)
